export default abstract class DynamicCollection extends Array {
    /**
     * Creates a new DynamicCollection instance.
     *
     * DynamicCollection is an extension of the native Array object thus
     * implementing all of Array's methods and properties.
     *
     * @name DynamicCollection
     * @constructor
     * @extends Array
     * @param {DynamicRecord.Model} Model	The Model constructor to use for
     *                              this collection
     */
    constructor(Model: any, ...data: any[]);
    /**
     * Returns a native array of data objects
     *
     * @name data
     * @memberOf DynamicCollection
     * @type Array
     */
    get data(): Array<any>;
    /**
     * Converts an array of objects into a DynamicCollection. If an element in
     * the array is not an object, it will be skipped.
     *
     * @method fromArray
     * @memberOf DynamicCollection
     * @static
     * @param {Array} array	Array to be converted into a DynamicCollection
     * @return {DynamicCollection}
     */
    static fromArray(arr: Array<any>, Model: any): void;
    /**
     * Save all the model instances in the DynamicCollection.
     *
     * Simply calls all the individual model's `save()` method.
     *
     * @method saveAll
     * @memberOf DynamicCollection
     * @instance
     * @return {Promise} - Return promise of this DynamicCollection instance
     */
    saveAll(): Promise<DynamicCollection>;
    /**
     * Destroy all the model instances in the DynamicCollection.
     *
     * Simply calls all the individual model's `destroy()` method.
     *
     * @method dropAll
     * @memberOf DynamicCollection
     * @instance
     * @return {Promise} - Return promise of this DynamicCollection instance
     */
    dropAll(): Promise<DynamicCollection>;
}
